@@ -47,7 +47,7 @@ NULL
 # Loglogistic Distribution Definition
 #-------------------------------------------------------------
 Loglogistic <- R6::R6Class("Loglogistic", inherit = SDistribution, lock_objects = F)
-Loglogistic$set("public","name","Log-Logistic")
+Loglogistic$set("public","name","Loglogistic")
 Loglogistic$set("public","short_name","LLogis")
 Loglogistic$set("public","description","Log-Logistic Probability Distribution.")
 Loglogistic$set("public","package","distr6")
@@ -144,3 +144,9 @@ Loglogistic$set("public","initialize",function(scale = 1, shape = 1, location =
                    variateForm = "univariate")
   invisible(self)
 })
+
+.distr6$distributions = rbind(.distr6$distributions,
+                              data.table::data.table(ShortName = "LLogis", ClassName = "Loglogistic",
+                                                     Type = "\u211D+", ValueSupport = "continuous",
+                                                     VariateForm = "univariate",
+                                                     Package = "distr6"))
