@@ -225,3 +225,9 @@ Triangular$set("public","initialize",function(lower = 0, upper = 1, mode = (lowe
                    variateForm = "univariate")
   invisible(self)
 })
+
+.distr6$distributions = rbind(.distr6$distributions,
+                              data.table::data.table(ShortName = "Tri", ClassName = "Triangular",
+                                                     Type = "\u211D", ValueSupport = "continuous",
+                                                     VariateForm = "univariate",
+                                                     Package = "distr6"))
