@@ -25,13 +25,11 @@ test_that("statistics",{
   expect_equal(s$mean(), NaN)
   expect_equal(StudentT$new(df = 2)$mean(), 0)
   expect_equal(s$variance(), NaN)
-  expect_equal(StudentT$new(df = 2)$variance(), Inf)
   expect_equal(StudentT$new(df = 3)$variance(), 3)
   expect_equal(StudentT$new(df = 4)$skewness(), 0)
   expect_equal(s$skewness(), NaN)
   expect_equal(StudentT$new(df = 5)$kurtosis(T), 6)
   expect_equal(StudentT$new(df = 5)$kurtosis(F), 9)
-  expect_equal(StudentT$new(df = 4)$kurtosis(), Inf)
   expect_equal(StudentT$new(df = 1)$kurtosis(), NaN)
   expect_equal(s$entropy(), digamma(1) - digamma(1/2) + log(beta(1/2, 1/2), 2))
   expect_equal(s$mgf(0), NaN)
